# Authors

Fluidsim has first been developed by
[Pierre Augier](http://www.legi.grenoble-inp.fr/people/Pierre.Augier/) (CNRS
researcher at [LEGI](http://www.legi.grenoble-inp.fr), Grenoble) at KTH
(Stockholm) as a numerical code to solve fluid equations in a periodic
two-dimensional space with pseudo-spectral methods.

Fluidsim has been greatly improved during Ashwin Vishnu PhD at KTH (Stockholm).

The main contributors are:

- [Pierre Augier (LEGI, CNRS, UGA)](http://www.legi.grenoble-inp.fr/people/Pierre.Augier)
- [Ashwin Vishnu (KTH)](https://www.mech.kth.se/mech/info_staff.xhtml?ID=381)
- [Cyrille Bonamy (LEGI, CNRS, UGA)](http://www.legi.grenoble-inp.fr/web/spip.php?auteur223)
- [Miguel Calpe Linares (LEGI, CNRS, UGA)](http://www.legi.grenoble-inp.fr/web/spip.php?auteur328)
- [Jason Reneuve (ENS Lyon)](http://www.ens-lyon.fr/PHYSIQUE/presentation/anciens/reneuve-jason)
- Antoine Bardant (LEGI)
- [Vincent Labarre](https://www.researchgate.net/profile/Vincent-Labarre)
  ([OCA](https://www.oca.eu/fr/fluid))
